django-salmonella
=================

A raw_id_fields widget replacement that handles display of an object's string value on change and can be overridden via a template.

For more information please [Read the Docs](http://readthedocs.org/docs/django-salmonella/en/latest/)
